#!/bin/sh
#
# rcstart - Disable or enable SysV init scripts for specified services.
#
# Copyright (c) 2000-2007 Occam's Razor. All rights reserved.
#
# See the LICENSE file distributed with this code for restrictions on its use
# and further distribution.
# Original distribution available at <http://www.occam.com/tools/>.
#
# $Id: rcstart.sh,v 1.7 2007/04/01 11:59:06 leonvs Exp $
#
# TODO
#	integration w/ chkconfig? or should they remain independent?
#	support for Mac OS X startup items?
#

PATH=/bin:/usr/bin

usage () {
	echo "$VERSION
usage:	$progname { -h | -V }
	$progname { -y | -n } service [service...]

	-h: Prints this usage summary.
	-V: Prints version number and exits.
	-y: Enables service startup at boot.
	-n: Disables service startup at boot.
	'service' is a system service defined by the existence of an init script
		by the same name." >&2
	exit 2
}

setup () {
	progname=`basename $0`
	VERSION="$progname 1.7"

	while getopts hVyn c; do
		case $c in
			h)	usage;;
			V)	echo $VERSION
				exit 2;;
			y|n)	START=$c;;
			\?)	usage;;
		esac
	done
	shift `expr $OPTIND - 1`

	# Need at least one argument.
	[ $# -ge 1 ] || usage

	# Need either -y or -n.
	[ -z $START ] && usage

	services=$*

	ENABLED_PREFIX="S"
	DISABLED_PREFIX="s"
	case $START in
		y)	prefixOld=$DISABLED_PREFIX
			prefixNew=$ENABLED_PREFIX
			actionMsg="enabled"
			;;
		n)	prefixOld=$ENABLED_PREFIX
			prefixNew=$DISABLED_PREFIX
			actionMsg="disabled"
			;;
	esac

	os=`uname -s`
	case $os in
		DYNIX/ptx)	initDir="/etc";;
		HP-UX)	initDir="/sbin";;
		IRIX)	initDir="/etc";;
		Linux)	initDir="/etc/rc.d";;
		SunOS)	initDir="/etc";;
		*)	error "Unknown operating system.";;
	esac
}

error () {
	msg=$*
	echo "$progname: $msg" >&2
	cleanup 2
}

cleanup () {
	status=$1
	exit $status
}

setup $*
for service in $services; do
	for rcDir in `ls -d ${initDir}/rc?.d`; do
		for initScript in `ls ${rcDir}/${prefixOld}*${service} 2>/dev/null`; do
			# Get number used for ordering init script.
			# Use colons as separators in sed command,
			# to avoid conflicts with slashes in filenames.
			bootOrder=`echo $initScript | \
				sed "s:^${rcDir}/${prefixOld}::" | \
				sed "s:${service}\\\$::"`
			initScriptNew="${rcDir}/${prefixNew}${bootOrder}${service}"
			mv $initScript $initScriptNew || \
				error "Can't rename $initScript."
			echo "$initScript $actionMsg"
		done
	done
done
cleanup 0
